@@ -242,6 +242,10 @@ profile_notify_sensitivity_cb (TerminalProfile *profile,
 		SET_SENSITIVE ("bell-checkbutton",
 		               !terminal_profile_property_locked (profile, TERMINAL_PROFILE_SILENT_BELL));
 
+	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_COPY_SELECTION))
+		SET_SENSITIVE ("copy-checkbutton",
+		               !terminal_profile_property_locked (profile, TERMINAL_PROFILE_COPY_SELECTION));
+
 	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_WORD_CHARS))
 		SET_SENSITIVE ("word-chars-entry",
 		               !terminal_profile_property_locked (profile, TERMINAL_PROFILE_WORD_CHARS));
@@ -468,7 +472,6 @@ profile_palette_notify_colorpickers_cb (TerminalProfile *profile,
 static void
 custom_command_entry_changed_cb (GtkEntry *entry)
 {
-#if GTK_CHECK_VERSION (2, 16, 0)
 	const char *command;
 	GError *error = NULL;
 
@@ -490,7 +493,6 @@ custom_command_entry_changed_cb (GtkEntry *entry)
 
 		g_error_free (error);
 	}
-#endif /* GTK+ >= 2.16.0 */
 }
 
 static void
@@ -943,6 +945,8 @@ terminal_profile_edit (TerminalProfile *profile,
 	CONNECT ("use-theme-colors-checkbutton", TERMINAL_PROFILE_USE_THEME_COLORS);
 	CONNECT ("word-chars-entry", TERMINAL_PROFILE_WORD_CHARS);
 	CONNECT_WITH_FLAGS ("bell-checkbutton", TERMINAL_PROFILE_SILENT_BELL, FLAG_INVERT_BOOL);
+	/* CONNECT_WITH_FLAGS ("copy-checkbutton", TERMINAL_PROFILE_COPY_SELECTION, FLAG_INVERT_BOOL); */
+	CONNECT ("copy-checkbutton", TERMINAL_PROFILE_COPY_SELECTION);
 
 #undef CONNECT
 #undef CONNECT_WITH_FLAGS
