@@ -29,6 +29,10 @@
 #include "terminal-profile.h"
 #include "terminal-util.h"
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+ #include <gdk/gdkkeysyms-compat.h>
+#endif
+
 /* NOTES
  *
  * There are two sources of keybindings changes, from GSettings and from
@@ -59,6 +63,8 @@
 #define ACCEL_PATH_FULL_SCREEN          ACCEL_PATH_ROOT "ViewFullscreen"
 #define ACCEL_PATH_RESET                ACCEL_PATH_ROOT "TerminalReset"
 #define ACCEL_PATH_RESET_AND_CLEAR      ACCEL_PATH_ROOT "TerminalResetClear"
+#define ACCEL_PATH_PREV_PROFILE         ACCEL_PATH_ROOT "ProfilePrevious"
+#define ACCEL_PATH_NEXT_PROFILE         ACCEL_PATH_ROOT "ProfileNext"
 #define ACCEL_PATH_PREV_TAB             ACCEL_PATH_ROOT "TabsPrevious"
 #define ACCEL_PATH_NEXT_TAB             ACCEL_PATH_ROOT "TabsNext"
 #define ACCEL_PATH_SET_TERMINAL_TITLE   ACCEL_PATH_ROOT "TerminalSetTitle"
@@ -82,8 +88,10 @@
 #define KEY_NEW_PROFILE         "new-profile"
 #define KEY_NEW_TAB             "new-tab"
 #define KEY_NEW_WINDOW          "new-window"
+#define KEY_NEXT_PROFILE        "next-profile"
 #define KEY_NEXT_TAB            "next-tab"
 #define KEY_PASTE               "paste"
+#define KEY_PREV_PROFILE        "prev-profile"
 #define KEY_PREV_TAB            "prev-tab"
 #define KEY_RESET_AND_CLEAR     "reset-and-clear"
 #define KEY_RESET               "reset"
@@ -210,6 +218,14 @@ static KeyEntry terminal_entries[] =
 		N_("Reset and Clear"),
 		KEY_RESET_AND_CLEAR, ACCEL_PATH_RESET_AND_CLEAR, 0, 0, NULL, FALSE, TRUE
 	},
+	{
+		N_("Switch to Previous Profile"),
+		KEY_PREV_PROFILE, ACCEL_PATH_PREV_PROFILE, GDK_MOD1_MASK, GDK_Page_Up, NULL, FALSE, TRUE
+	},
+	{
+		N_("Switch to Next Profile"),
+		KEY_NEXT_PROFILE, ACCEL_PATH_NEXT_PROFILE, GDK_MOD1_MASK, GDK_Page_Down, NULL, FALSE, TRUE
+	},
 };
 
 static KeyEntry tabs_entries[] =
@@ -319,7 +335,7 @@ enum
 };
 
 static void keys_change_notify (GSettings *settings,
-                                gchar *key,
+                                const gchar *key,
                                 gpointer user_data);
 
 static void accel_changed_callback (GtkAccelGroup  *accel_group,
@@ -457,7 +473,7 @@ update_model_foreach (GtkTreeModel *model,
 
 static void
 keys_change_notify (GSettings *settings,
-                    gchar *key,
+                    const gchar *key,
                     gpointer user_data)
 {
 	GVariant *val;
@@ -647,7 +663,6 @@ static gboolean
 sync_idle_cb (gpointer data)
 {
 	GSettings *changeset;
-	GError *error = NULL;
 
 	_terminal_debug_print (TERMINAL_DEBUG_ACCELS,
 	                       "GSettings sync handler\n");
@@ -814,7 +829,7 @@ accel_edited_callback (GtkCellRendererAccel *cell,
 			                            GTK_BUTTONS_OK,
 			                            _("The shortcut key “%s” is already bound to the “%s” action"),
 			                            name,
-			                            
+
 other_key->user_visible_name ? _(other_key->user_visible_name) : other_key->gsettings_key);
 			g_free (name);
 
