@@ -84,6 +84,7 @@ enum
     PROP_USE_THEME_COLORS,
     PROP_VISIBLE_NAME,
     PROP_WORD_CHARS,
+    PROP_COPY_SELECTION,
     LAST_PROP
 };
 
@@ -114,6 +115,7 @@ enum
 #define KEY_SCROLL_ON_KEYSTROKE "scroll-on-keystroke"
 #define KEY_SCROLL_ON_OUTPUT "scroll-on-output"
 #define KEY_SILENT_BELL "silent-bell"
+#define KEY_COPY_SELECTION "copy-selection"
 #define KEY_TITLE_MODE "title-mode"
 #define KEY_TITLE "title"
 #define KEY_UPDATE_RECORDS "update-records"
@@ -154,6 +156,7 @@ enum
 #define DEFAULT_SCROLL_ON_KEYSTROKE   (TRUE)
 #define DEFAULT_SCROLL_ON_OUTPUT      (FALSE)
 #define DEFAULT_SILENT_BELL           (FALSE)
+#define DEFAULT_COPY_SELECTION        (FALSE)
 #define DEFAULT_TITLE_MODE            (TERMINAL_TITLE_REPLACE)
 #define DEFAULT_TITLE                 (N_("Terminal"))
 #define DEFAULT_UPDATE_RECORDS        (TRUE)
@@ -285,7 +288,7 @@ static void ensure_pixbuf_property (TerminalProfile *profile,
                                     guint pixbuf_prop_id,
                                     gboolean *load_failed);
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 static GQuark gsettings_key_quark;
 
 G_DEFINE_TYPE (TerminalProfile, terminal_profile, G_TYPE_OBJECT);
@@ -1251,6 +1254,7 @@ terminal_profile_class_init (TerminalProfileClass *klass)
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (SCROLL_ON_KEYSTROKE, DEFAULT_SCROLL_ON_KEYSTROKE, KEY_SCROLL_ON_KEYSTROKE);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (SCROLL_ON_OUTPUT, DEFAULT_SCROLL_ON_OUTPUT, KEY_SCROLL_ON_OUTPUT);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (SILENT_BELL, DEFAULT_SILENT_BELL, KEY_SILENT_BELL);
+	TERMINAL_PROFILE_PROPERTY_BOOLEAN (COPY_SELECTION, DEFAULT_COPY_SELECTION, KEY_COPY_SELECTION);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (UPDATE_RECORDS, DEFAULT_UPDATE_RECORDS, KEY_UPDATE_RECORDS);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_CUSTOM_COMMAND, DEFAULT_USE_CUSTOM_COMMAND, KEY_USE_CUSTOM_COMMAND);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_CUSTOM_DEFAULT_SIZE, DEFAULT_USE_CUSTOM_DEFAULT_SIZE, KEY_USE_CUSTOM_DEFAULT_SIZE);
